/* ==========================================================
 * Program: 21-HorseshoeP2P3.cpp
 * ==========================================================
 * The program checks the covering relations between some 
 * h-sets related to the connecting orbit between P2 and P3
 * From the program 06:
	P2 ~ 1.294511656;	dom. eigenvalue approx. 28
	P3 ~ 1.712042516;	dom. eigenvalue approx. 5
 * ==========================================================*/ 

#include <iostream>
using namespace std;

#include "capd/capdlib.h"
using namespace capd;
using namespace capd::alglib;
using namespace capd::matrixAlgorithms;
#include "capd/covrel/HSet2D.h"
#include "capd/dynsys/DynSysMap.h"

#include "utils.h"
typedef capd::covrel::HSet2D<DMatrix, IMatrix> HSet2D;


int main(int argc, char* argv[])
{  	
	cout.precision(8);
   	
	mojUklad hyperion;					// structure storing Poincare map of Hyperion rotation system, see utils
	//---------------------------------stationary points------------------------------------------------------	
	interval z3=1.711370591161749;
	interval z2=1.294219468594181;			// approximately
	IMatrix Mv3(3,3), Mv2(3,3);
	IVector p3=hyperion.pStNaPi2(z3,Mv3);	// rigorously, small intervals containing P3 and P2
	IVector p2=hyperion.pStNaPi2(z2,Mv2);	// eigenvectors stored in matrices Mv
	
	//---------------------------------base points of h-sets------------------------------------------------------	
	IVector o[6];
	o[0]=p3;
	o[1][0]=1.5569;
	o[1][1]=1.70419;
	o[2][0]=1.49724;	
	o[2][1]=1.67606;
	o[3][0]=1.21834;		
	o[3][1]=1.61946;
	o[4][0]=1.55807;
	o[4][1]=1.30592;
	o[5]=p2;
	
	//------------------------------------the base cubes of h-sets ----------------------------------------------------
	double r = 1*pow(10,-3);
	IVector b[6];
	b[0][0]=interval(-8*r,8*r);
	b[0][1]=interval(-8*r,8*r);
	b[1][0]=interval(-5*r,5*r);
	b[1][1]=interval(-20*r,20*r);
	b[2][0]=interval(-5*r,5*r);
	b[2][1]=interval(-15*r,15*r);
	b[3][0]=interval(-1*r,1*r);
	b[3][1]=interval(-30*r,30*r);
	b[4][0]=interval(-1*r,1*r);
	b[4][1]=interval(-10*r,10*r);
	b[5][0]=interval(-2*r,2*r);
	b[5][1]=interval(-2*r,2*r);
   	//--------------------------------- covering check (some cases with 10x10 griding)------------------------
	try{
		if(hyperion.covers(b[0],Mv3,o[0],b[0],Mv3,o[0],10,10))
		{			
			cout << "Covering! N0 =P=> N0" << endl;	
			cout << "----------------------------------------------------" << endl;		
		} 
		if(hyperion.covers(b[0],Mv3,o[0],b[1],Mv3,o[1]))
		{			
			cout << "Covering! N0 =P=> N1" << endl;	
			cout << "----------------------------------------------------" << endl;		
		}
		if(hyperion.covers(b[1],Mv3,o[1],b[2],Mv3,o[2],10,10))
		{			
			cout << "Covering! N1 =P=> N2" << endl;	
			cout << "----------------------------------------------------" << endl;		
		}
		if(hyperion.covers(b[2],Mv3,o[2],b[3],Mv2,o[3],10,10))
		{			
			cout << "Covering! N2 =P=> N3" << endl;	
			cout << "----------------------------------------------------" << endl;		
		} 
		if(hyperion.covers(b[3],Mv2,o[3],b[4],Mv2,o[4]))
		{			
			cout << "Covering! N3 =P=> N4" << endl;	
			cout << "----------------------------------------------------" << endl;		
		}
		if(hyperion.covers(b[4],Mv2,o[4],b[5],Mv2,o[5]))
		{			
			cout << "Covering! N4 =P=> N5" << endl;	
			cout << "----------------------------------------------------" << endl;		
		}
		if(hyperion.covers(b[5],Mv2,o[5],b[5],Mv2,o[5]))
		{			
			cout << "Covering! N5 =P=> N5" << endl;	
			cout << "----------------------------------------------------" << endl;		
		}
		}
	catch(exception& e)
		{
    		cout << "\n\nException caught: "<< e.what() << endl;
		}
  return 0;
} 

/* OUTPUT: 
Covering! N0 =P=> N0
----------------------------------------------------
Covering! N0 =P=> N1
----------------------------------------------------
Covering! N1 =P=> N2
----------------------------------------------------
Covering! N2 =P=> N3
----------------------------------------------------
Covering! N3 =P=> N4
----------------------------------------------------
Covering! N4 =P=> N5
----------------------------------------------------
Covering! N5 =P=> N5
----------------------------------------------------

*/
