/* ==========================================================
 * Program: 25a-HorseshoeP1P1.cpp
 * ==========================================================
 * The program checks the covering relations between some 
 * h-sets related to the connecting orbit between P1 and P1
 * From the program 06:
     P1 ~ 1.098956671;	dom. eigenvalue approx. 264
 * ==========================================================*/ 

#include <iostream>
using namespace std;

#include "capd/capdlib.h"
using namespace capd;
using namespace capd::alglib;
using namespace capd::matrixAlgorithms;
#include "capd/covrel/HSet2D.h"
#include "capd/dynsys/DynSysMap.h"

#include "utils.h"
typedef capd::covrel::HSet2D<DMatrix, IMatrix> HSet2D;


int main(int argc, char* argv[])
{  	
	cout.precision(8);
	
	//------------------------------Hyperion Poincare Map---------------------------------------------
	mojUklad hyperion;					// structure storing Poincare map of Hyperion rotation system, see utils
	mojUklad hyperion2(2);				// structure storing P^2
	
	//---------------------------------stationary points------------------------------------------------------	
	interval z1=1.099105177037064;				// approximately
	IMatrix Mv1(3,3);
	IVector p1=hyperion.pStNaPi2(z1,Mv1);	// rigorously, small interval containing P1
	//cout << "Mv1=" << Mv1 << endl;	// eigenvectors' matrix
	
	//---------------------------------base points of h-sets------------------------------------------------------	
	IVector o[2];
	o[0]=p1;
	o[1][0]=1.58669;
	o[1][1]=1.10102;
	
	//------------------------------------the base cubes of h-sets ----------------------------------------------------
	double r = 1*pow(10,-3);
	IVector b[2];
	b[0][0]=interval(-r,r);
	b[0][1]=interval(-100*r,100*r);
	b[1][0]=interval(-0.1*r,0.1*r);
	b[1][1]=interval(-60*r,60*r);
	
   	//--------------------------------- covering check (some cases with 10x10 griding)------------------------
	try{
		if(hyperion.covers(b[0],Mv1,o[0],b[0],Mv1,o[0]))
		{			
			cout << "Covering! N0 =P=> N0" << endl;	
			cout << "----------------------------------------------------" << endl;		
		}
		if(hyperion.covers(b[0],Mv1,o[0],b[1],Mv1,o[1]))
		{			
			cout << "Covering! N0 =P=> N1" << endl;	
			cout << "----------------------------------------------------" << endl;		
		}
		if(hyperion2.covers(b[1],Mv1,o[1],b[0],Mv1,o[0],10,10))
		{			
			cout << "Covering! N1 =P^2=> N0" << endl;	
			cout << "----------------------------------------------------" << endl;		
		}
		if(hyperion2.covers(b[1],Mv1,o[1],b[1],Mv1,o[1],10,10))
		{			
			cout << "Covering! N1 =P^2=> N1" << endl;	
			cout << "----------------------------------------------------" << endl;		
		}
		}
	catch(exception& e)
		{
    		cout << "\n\nException caught: "<< e.what() << endl;
		}
  return 0;
} 

/* OUTPUT: 

Covering! N0 =P=> N0
----------------------------------------------------
Covering! N0 =P=> N1
----------------------------------------------------
Covering! N1 =P^2=> N0
----------------------------------------------------
Covering! N1 =P^2=> N1
----------------------------------------------------


*/
