/* ==========================================================
 * Program: 25b-HorseshoeP2P2.cpp
 * ==========================================================
 * The program checks the covering relations between some 
 * h-sets related to the connecting orbit between P2 and P2
 * From the program 06:
	P2 ~ 1.294511656;	dom. eigenvalue approx. 28
 * ==========================================================*/ 

#include <iostream>
using namespace std;

#include "capd/capdlib.h"
using namespace capd;
using namespace capd::alglib;
using namespace capd::matrixAlgorithms;
#include "capd/covrel/HSet2D.h"
#include "capd/dynsys/DynSysMap.h"

#include "utils.h"
typedef capd::covrel::HSet2D<DMatrix, IMatrix> HSet2D;


int main(int argc, char* argv[])
{  	
	cout.precision(8);
	
	//------------------------------Hyperion Poincare Map---------------------------------------------
	mojUklad hyperion;					// structure storing Poincare map of Hyperion rotation system, see utils
	mojUklad hyperion2(2);				// structure storing P^2
	
	//---------------------------------stationary points------------------------------------------------------	
	interval z2=1.294219468594181;			// approximately
	IMatrix Mv2(3,3);
	IVector p2=hyperion.pStNaPi2(z2,Mv2);	// rigorously, small interval containing P2
	//cout << "Mv2=" << Mv2 << endl;	// eigenvectors' matrix
	
	//---------------------------------base points of h-sets------------------------------------------------------	
	IVector o[2];
	o[0]=p2;
	o[1][0]=1.62953;
	o[1][1]=1.35174;
	
	//------------------------------------the base cubes of h-sets ----------------------------------------------------
	double r = 1*pow(10,-3);
	IVector b[2];
	b[0][0]=interval(-10*r,10*r);
	b[0][1]=interval(-200*r,200*r);
	b[1][0]=interval(-10*r,10*r);
	b[1][1]=interval(-150*r,150*r);
	
   	//--------------------------------- covering check (all with 10x10 griding)------------------------
	try{
		if(hyperion.covers(b[0],Mv2,o[0],b[0],Mv2,o[0],10,10))
		{			
			cout << "Covering! N0 =P=> N0" << endl;	
			cout << "----------------------------------------------------" << endl;		
		}
		if(hyperion.covers(b[0],Mv2,o[0],b[1],Mv2,o[1],10,10))
		{			
			cout << "Covering! N0 =P=> N1" << endl;	
			cout << "----------------------------------------------------" << endl;		
		}
		if(hyperion2.covers(b[1],Mv2,o[1],b[0],Mv2,o[0],10,10))
		{			
			cout << "Covering! N1 =P^2=> N0" << endl;	
			cout << "----------------------------------------------------" << endl;		
		}
		if(hyperion2.covers(b[1],Mv2,o[1],b[1],Mv2,o[1],20,20))
		{			
			cout << "Covering! N1 =P^2=> N1" << endl;	
			cout << "----------------------------------------------------" << endl;		
		}
		}
	catch(exception& e)
		{
    		cout << "\n\nException caught: "<< e.what() << endl;
		}
  return 0;
} 

/* OUTPUT: 

Covering! N0 =P=> N0
----------------------------------------------------
Covering! N0 =P=> N1
----------------------------------------------------
Covering! N1 =P^2=> N0
----------------------------------------------------
Covering! N1 =P^2=> N1
----------------------------------------------------



*/
